@@ -719,7 +719,7 @@ class xmlDoc():
                 if newAreaAction == "drop":
                     prevNode = oName.getparent().getparent().getprevious()
                     removePrevNodes = []
-                    while prevNode and self.getTypeField(prevNode) == "br":
+                    while prevNode is not None and self.getTypeField(prevNode) == "br":
                         removePrevNodes.append(prevNode)
                         prevNode = prevNode.getprevious()
                     for removeNode in removePrevNodes:
