@@ -228,8 +228,8 @@ class Git():
         new_index = path.join(git_dir, fn)
         if path.exists(old_index):
             try:
-                with open(old_index, 'r') as in_f:
-                    with writeFile(new_index) as out_f:
+                with open(old_index, 'rb') as in_f:
+                    with writeFile(new_index, binary=True) as out_f:
                         out_f.write(in_f.read())
                 return True
             except IOError:
