@@ -14,9 +14,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
 import sys
-from calculate.lib.datavars import ReadonlyVariable
+from ..datavars import ReadonlyVariable
 
 from . import X11
 from . import locale
@@ -27,7 +26,7 @@ from . import net
 from . import user
 from . import system
 from . import action
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 setLocalTranslate('cl_lib3',sys.modules[__name__])
 
 section = "main"
